@@ -18,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 /*
@@ -587,7 +587,7 @@ char * qfits_memory_falloc(
         /* Check offset request does not go past end of file */
         if (offs>=(size_t)sta.st_size) {
 			qfits_warning("qfits_memory_falloc(%s:%i): offset request exceeds file size (%zu > %zu) for file \"%s\"\n",
-						  srcname, srclin, offs, (size_t)sta.st_size);
+                                      srcname, srclin, offs, (size_t)sta.st_size, name);
             if (QFITS_MEMORY_MODE == 0) return NULL;
             else exit(1);
         }
